# clj Changelog

## 0.1.1 (2018/01/12)

* Add `fns.juxt`, `fns.inc`, `fns.dec`
* Fix an infinite loop in `seqs.cycle` when a generator was passed
* Fix `setup.py` issues when `LANG` isn’t set (contributed by @tdhopper)

## 0.1.0 (2016/09/08)

Initial release.
